@@ -37,7 +37,7 @@ r2_zeroinflated <- function(model, method = c("default", "correlation")) {
 
   mi <- insight::model_info(model, verbose = FALSE)
   if (!mi$is_zero_inflated) {
-    warning("Model has no zero-inflation component.")
+    insight::format_warning("Model has no zero-inflation component.")
   }
 
   if (method == "default") {
@@ -63,7 +63,6 @@ r2_zeroinflated <- function(model, method = c("default", "correlation")) {
   k <- length(insight::find_parameters(model)[["conditional"]])
 
   y <- insight::get_response(model, verbose = FALSE)
-  # pred <- stats::predict(model, type = "response")
 
   var_fixed <- sum((stats::fitted(model) - mean(y))^2)
   var_resid <- sum(stats::residuals(model, type = "pearson")^2)
